|Build Status| |Code Coverage|

Compressed Fisher
=================


**Compressed Fisher** is a Python library containing tools for testing if Fisher forecasts using simulated components are converged. The library contains tools to compute standard Fisher estimates, estimate the level of bias due to the finite number of simulations, and compute the compressed Fisher information, as described Coulton & Wandelt (2023) and `Coulton et al (2022b) <https://arxiv.org/abs/2206.15450>`_. 

Please refer to `the documentation <https://compressedfisher.readthedocs.io/>`_ or the examples provided in the `examples folder <https://github.com/wcoulton/CompressedFisher/tree/main/examples>`_ to learn how to get started.

.. note::



.. |Build Status| image:: https://github.com/wcoulton/CompressedFisher/actions/workflows/ci.yml/badge.svg
   :target:  https://github.com/wcoulton/CompressedFisher/actions/workflows/ci.yml
.. |Code Coverage| image:: https://codecov.io/gh/wcoulton/CompressedFisher/branch/main/graph/badge.svg?token=Z00BO0FR6Q
   :target: https://codecov.io/gh/wcoulton/CompressedFisher/branch/main

